@@ -1,3 +1,3 @@
 from pkg_resources import declare_namespace
-declare_namespace('csvimport')
 
+declare_namespace("csvimport")
